///File : DevisText.cpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "DevisText.hpp"
//------------------------------------------------------------------------------

namespace mdo
{

//------------------------------------------------------------------------------
//---------------------------------- DevisText --------------------------------------
//------------------------------------------------------------------------------
bool DevisText::CalculSizeReal(wxDC *dc, const int &width, const int &askedHeight)
{
    if( m_devisCfg == NULL )
    {
        m_data.textToDraw = m_textToAddDescriptionList[m_textToAddId];
    }
    else
    {
        m_data.textToDraw = StrStdToWx(m_devisCfg->GetString(m_textToAddList[m_textToAddId]));
    }

    TextBase::CalculSizeReal(dc, width, askedHeight);
}
//------------------------------------------------------------------------------
DevisText::DevisText(ConfigManager *cfg, ConfigManager *devisCfg, DrawableObject *parrentSizer, const std::string &name) : TextBase(cfg, devisCfg, parrentSizer, name)
{
    m_typeName = MDO_DEVIS_TEXT_TYPE_NAME;
    SetConfigName(""); // Rechargement du prefix

    m_textToAddList[0] = "name";
    m_textToAddList[1] = "info";
    m_textToAddList[2] = "numDevis";
    m_textToAddList[3] = "description";

    m_textToAddDescriptionList[0] = _("Name");
    m_textToAddDescriptionList[1] = _("Information");
    m_textToAddDescriptionList[2] = _("Estimate  / invoice id");
    m_textToAddDescriptionList[3] = _("Description");
}
//------------------------------------------------------------------------------
void DevisText::LoadFromCfg(const std::string &name)
{
    TextBase::LoadFromCfg(name);
    m_textToAddId = m_cfg->GetInt(m_cfgPrefix + "textToAddId");

    if(m_textToAddId < 0 || m_textToAddId >= textToAddListNb )
    {
        throw ticpp::Exception("mdo::DevisText::LoadFromCfg : Unknown textToAddId !");
    }
}
//------------------------------------------------------------------------------
void DevisText::SaveToCfg(const std::string &name)
{
    TextBase::SaveToCfg(name);
    m_cfg->SetInt(m_cfgPrefix + "textToAddId", m_textToAddId);
}
//------------------------------------------------------------------------------
void DevisText::CreateToCfg(const std::string &name)
{
    TextBase::CreateToCfg(name);
    m_cfg->SetInt(m_cfgPrefix + "textToAddId", 0);

    LoadFromCfg();
}
//------------------------------------------------------------------------------
void DevisText::RemoveFromCfg(const std::string &name, const bool &withChilds)
{
    TextBase::RemoveFromCfg(name);
    m_cfg->RemoveInt(m_cfgPrefix + "textToAddId");
}
//------------------------------------------------------------------------------
void DevisText::EditPropertyDialog(DialogProperty *window)
{
    TextBase::EditPropertyDialog(window);

    wxPanel *PagePanel;
    wxBoxSizer *PageSizer;

    // Special Mdo
    PagePanel = new wxPanel(window->GetNotebook(), wxID_ANY);
    PageSizer = new wxBoxSizer(wxVERTICAL);

    wxArrayString wxTextToAddList(textToAddListNb, m_textToAddDescriptionList);
    window->AddParamCtrl(type_choice_index, PagePanel, PageSizer, m_cfgPrefix + "textToAddId", _("Text :"), static_cast<void*>(&wxTextToAddList));

    PagePanel->SetSizer(PageSizer);
    window->GetNotebook()->AddPage(PagePanel, _("Text"));
}
//------------------------------------------------------------------------------


} // namespace mdo
